---
title: Grouping
page_title: Grouping of Resources - Scheduler - Kendo UI for Vue
description: "Group resources when working with the Kendo UI Scheduler wrapper for Vue."
slug: resources_grouping_scheduler
position: 2
---

# Grouping of Resources

The Scheduler enables you to group its resources by using its `orientation` configuration.

The available options are:
* [Horizontal grouping](#toc-horizontal-grouping)
* [Vertical grouping](#toc-vertical-grouping)
* [Grouping by dates](#toc-date-grouping)

> The `agenda` view is always in vertical orientation.

## Horizontal Grouping

The following example demonstrates how to group the resources horizontally. To control the direction of the grouping, set the `orientation` property. By default, `orientation` is set to `horizontal`.

{% meta height:665 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-schedulerdatasource ref="remoteDataSource"  
							   :batch="true"
							   transport-read-url="https://demos.telerik.com/kendo-ui/service/meetings"
							   transport-read-data-type="jsonp"
							   transport-update-url="https://demos.telerik.com/kendo-ui/service/meetings/update"
							   transport-update-data-type="jsonp"
							   transport-create-url="https://demos.telerik.com/kendo-ui/service/meetings/create"
							   transport-create-data-type="jsonp"
							   transport-destroy-url="https://demos.telerik.com/kendo-ui/service/meetings/destroy"
							   transport-destroy-data-type="jsonp"
							   :transport-parameter-map="parameterMap"
							   schema-model-id="meetingID"
							   :schema-model-fields="fields">
    </kendo-schedulerdatasource>

    <kendo-scheduler data-source-ref="remoteDataSource"
					 :date="date"
					 :height="600"
					 :group="group"
					 :timezone="'Etc/UTC'">
		<kendo-scheduler-view :type="'day'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'week'" :selected="true"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'month'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'timeline'"></kendo-scheduler-view>
		<kendo-scheduler-resource :field="'roomId'" :name="'Rooms'" :title="'Room'" :data-source="resourceDataSource1"></kendo-scheduler-resource>
		<kendo-scheduler-resource :field="'attendees'" :name="'Attendees'" :title="'Attendees'" multiple="true" :data-source="resourceDataSource2"></kendo-scheduler-resource>
    </kendo-scheduler>
</div>
```
```js
Vue.use(SchedulerInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
    methods: {
		parameterMap: function (options, operation) {
			if (operation !== 'read' && options.models) {
				return {models: kendo.stringify(options.models)}
			}
		}
    },    
  data () {
    return {
		date: new Date('2013/6/13'),	       
        fields: {
			meetingID: { from: 'MeetingID', type: 'number' },
			title: { from: 'Title', defaultValue: 'No title', validation: { required: true } },
			start: { type: 'date', from: 'Start' },
			end: { type: 'date', from: 'End' },
			startTimezone: { from: 'StartTimezone' },
			endTimezone: { from: 'EndTimezone' },
			description: { from: 'Description' },
			recurrenceId: { from: 'RecurrenceID' },
			recurrenceRule: { from: 'RecurrenceRule' },
			recurrenceException: { from: 'RecurrenceException' },
            roomId: { from: 'RoomID', nullable: true },
            attendees: { from: 'Attendees', nullable: true },
			isAllDay: { type: 'boolean',	 from: 'IsAllDay' }
		},
        group: {           
            resources: ["Rooms"],
			orientiation: "horizontal"
        },
		resourceDataSource1: [
			{
				text: "Meeting Room 101", // The text of the resource instance
				value: 1, // The identifier of the resource instance. Use that value to assign an event to this instance.
				color: "#1c9ec4" // Used as the background of events assigned to this resource.
			},
			{ text: "Meeting Room 102", value: 2, color: "#ff7663" }
		],
		resourceDataSource2: [
			{ text: 'Alex', value: 1, color: '#f8a398' },
			{ text: 'Bob', value: 2, color: '#51a0ed' },
			{ text: 'Charlie', value: 3, color: '#56ca85' }
		]
	}
	}
})
```
{% endmeta %}

## Vertical Grouping

The following example demonstrates how to group the resources vertically. To control the direction of the grouping, set the `orientation` property to `vertical`.

```html
<div id="vueapp" class="vue-app">
    <kendo-schedulerdatasource ref="remoteDataSource"  
							   :batch="true"
							   transport-read-url="https://demos.telerik.com/kendo-ui/service/meetings"
							   transport-read-data-type="jsonp"
							   transport-update-url="https://demos.telerik.com/kendo-ui/service/meetings/update"
							   transport-update-data-type="jsonp"
							   transport-create-url="https://demos.telerik.com/kendo-ui/service/meetings/create"
							   transport-create-data-type="jsonp"
							   transport-destroy-url="https://demos.telerik.com/kendo-ui/service/meetings/destroy"
							   transport-destroy-data-type="jsonp"
							   :transport-parameter-map="parameterMap"
							   schema-model-id="meetingID"
							   :schema-model-fields="fields">
    </kendo-schedulerdatasource>

    <kendo-scheduler data-source-ref="remoteDataSource"
					 :date="date"
					 :height="600"
					 :group="group"
					 :timezone="'Etc/UTC'">
		<kendo-scheduler-view :type="'day'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'week'" :selected="true"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'month'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'timeline'"></kendo-scheduler-view>
		<kendo-scheduler-resource :field="'roomId'" :name="'Rooms'" :title="'Room'" :data-source="resourceDataSource1"></kendo-scheduler-resource>
		<kendo-scheduler-resource :field="'attendees'" :name="'Attendees'" :title="'Attendees'" multiple="true" :data-source="resourceDataSource2"></kendo-scheduler-resource>
    </kendo-scheduler>
</div>
```
```js
Vue.use(SchedulerInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
    methods: {
		parameterMap: function (options, operation) {
			if (operation !== 'read' && options.models) {
				return {models: kendo.stringify(options.models)}
			}
		}
    },    
  data () {
    return {
		date: new Date('2013/6/13'),	       
        fields: {
			meetingID: { from: 'MeetingID', type: 'number' },
			title: { from: 'Title', defaultValue: 'No title', validation: { required: true } },
			start: { type: 'date', from: 'Start' },
			end: { type: 'date', from: 'End' },
			startTimezone: { from: 'StartTimezone' },
			endTimezone: { from: 'EndTimezone' },
			description: { from: 'Description' },
			recurrenceId: { from: 'RecurrenceID' },
			recurrenceRule: { from: 'RecurrenceRule' },
			recurrenceException: { from: 'RecurrenceException' },
            roomId: { from: 'RoomID', nullable: true },
            attendees: { from: 'Attendees', nullable: true },
			isAllDay: { type: 'boolean', from: 'IsAllDay' }
		},
        group: {           
            resources: ["Rooms", "Attendees"],
			orientation: "vertical"
        },
		resourceDataSource1: [
			{
				text: "Meeting Room 101", // Text of the resource instance
				value: 1, // The identifier of the resource instance. Use that value to assign an event to this instance.
				color: "#1c9ec4" // Used as the background of events assigned to this resource.
			},
			{ text: "Meeting Room 102", value: 2, color: "#ff7663" }
		],
		resourceDataSource2: [
			{ text: 'Alex', value: 1, color: '#f8a398' },
			{ text: 'Bob', value: 2, color: '#51a0ed' },
			{ text: 'Charlie', value: 3, color: '#56ca85' }
		]
	}
	}
})
```

## Grouping by Dates

The following example demonstrates how to group the resources both vertically and by date. To control the direction of the grouping, set the `orientation` property. To control the grouping by dates, set the `date` option to `true`.

```html
<div id="vueapp" class="vue-app">
    <kendo-schedulerdatasource ref="remoteDataSource"  
							   :batch="true"
							   transport-read-url="https://demos.telerik.com/kendo-ui/service/meetings"
							   transport-read-data-type="jsonp"
							   transport-update-url="https://demos.telerik.com/kendo-ui/service/meetings/update"
							   transport-update-data-type="jsonp"
							   transport-create-url="https://demos.telerik.com/kendo-ui/service/meetings/create"
							   transport-create-data-type="jsonp"
							   transport-destroy-url="https://demos.telerik.com/kendo-ui/service/meetings/destroy"
							   transport-destroy-data-type="jsonp"
							   :transport-parameter-map="parameterMap"
							   schema-model-id="meetingID"
							   :schema-model-fields="fields">
    </kendo-schedulerdatasource>

    <kendo-scheduler data-source-ref="remoteDataSource"
					 :date="date"
					 :height="600"
					 :group="group"
					 :timezone="'Etc/UTC'">
		<kendo-scheduler-view :type="'day'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'week'"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'month'" :selected="true"></kendo-scheduler-view>
		<kendo-scheduler-view :type="'timeline'"></kendo-scheduler-view>
		<kendo-scheduler-resource :field="'roomId'" :name="'Rooms'" :title="'Room'" :data-source="resourceDataSource1"></kendo-scheduler-resource>
		<kendo-scheduler-resource :field="'attendees'" :name="'Attendees'" :title="'Attendees'" multiple="true" :data-source="resourceDataSource2"></kendo-scheduler-resource>
    </kendo-scheduler>
</div>
```
```js
Vue.use(SchedulerInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
    methods: {
		parameterMap: function (options, operation) {
			if (operation !== 'read' && options.models) {
				return {models: kendo.stringify(options.models)}
			}
		}
    },    
  data () {
    return {
		date: new Date('2013/6/13'),	       
        fields: {
			meetingID: { from: 'MeetingID', type: 'number' },
			title: { from: 'Title', defaultValue: 'No title', validation: { required: true } },
			start: { type: 'date', from: 'Start' },
			end: { type: 'date', from: 'End' },
			startTimezone: { from: 'StartTimezone' },
			endTimezone: { from: 'EndTimezone' },
			description: { from: 'Description' },
			recurrenceId: { from: 'RecurrenceID' },
			recurrenceRule: { from: 'RecurrenceRule' },
			recurrenceException: { from: 'RecurrenceException' },
            roomId: { from: 'RoomID', nullable: true },
            attendees: { from: 'Attendees', nullable: true },
			isAllDay: { type: 'boolean', from: 'IsAllDay' }
		},
        group: {           
            resources: ["Rooms"],
			date: true,
			orientation: "vertical"
        },
		resourceDataSource1: [
			{
				text: "Meeting Room 101", // The text of the resource instance.
				value: 1, // The identifier of the resource instance. Use that value to assign an event to this instance.
				color: "#1c9ec4" // Used as the background of events assigned to this resource.
			},
			{ text: "Meeting Room 102", value: 2, color: "#ff7663" }
		],
		resourceDataSource2: [
			{ text: 'Alex', value: 1, color: '#f8a398' },
			{ text: 'Bob', value: 2, color: '#51a0ed' },
			{ text: 'Charlie', value: 3, color: '#56ca85' }
		]
	}
	}
})
```

## Suggested Links

* [Kendo UI Scheduler for jQuery](https://docs.telerik.com/kendo-ui/controls/scheduling/scheduler/overview)
* [API Reference of the Scheduler Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/scheduler)
